##  Step 4: Add Shapes and Fact Sheets to Your Diagram
You can add basic shapes and fact sheets from your inventory to build your diagram.
### Add Shapes
  * From the shape library: Select a shape and drag it into the editor.
  * From the toolbar: Choose the Shapes. Select a shape from the available options.


To access more shapes, choose More Shapes at the bottom of the shape library.
![Diagram editor with various shapes on a grid canvas and shape options on the left panel.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio335f2158936c41d98160e6cfd07ef4ea_LowRes.gif)
Adding Shapes to the Canvas
### Add Fact Sheets from the Inventory
  1. Choose the plus icon in the toolbar.
Alternatively, right-click anywhere in the editor. Choose Insert from Inventory.
  2. Filter to find the fact sheets that you want to insert.
To add individual fact sheets, select the desired fact sheets and choose Insert selected.
To add all fact sheets of a specific type, filter for the type and choose Insert all.


The shapes and fact sheets appear in the editor. You can adjust their style, position, and alignment by clicking and dragging them. You can also use the format panel and toolbar to customize their appearance.
To learn how to add SAP-specific shapes, see [SAP BTP Reference Architecture Templates](https://help.sap.com/docs/leanix/ea/sap-btp-reference-architecture-templates?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to access and use SAP BTP reference architecture templates in SAP LeanIX diagrams to design and customize SAP BTP solution architecture, ensuring alignment with SAP best practices.").
